@@ -1,35 +1,25 @@
 import numpy as np
 import pandas as pd
 
-from density_estimator import DensityEstimator
+from .density_estimator import DensityEstimator
 import ashfunc
-import bandwidth_selection
+from . import bandwidth_selection
 
 class ASH(DensityEstimator):
     def __init__(self,
                  h='scott',
                  q=10,
                  n_mc = 10000,
-                 mc_seed = None,
                  bounds = [],
-                 preprocessing='whitening',
-                 forbid_null_value=False,
-                 n_jobs = 1,
-                 verbose=0,
-                 verbose_heading_level=1):
+                 verbose=0):
 
         super().__init__(bounds = bounds,
-                         forbid_null_value=forbid_null_value,
-                         verbose=verbose,
-                         verbose_heading_level=verbose_heading_level)
+                         verbose=verbose)
 
-        self.preprocessing = preprocessing
         self.h = h
         self._h = None
         self.q = q
         self.n_mc = n_mc
-        self.mc_seed = mc_seed
-        self.n_jobs = n_jobs
 
     def __repr__(self):
         if self._h is None:
@@ -82,8 +72,7 @@ class ASH(DensityEstimator):
         return(self)
 
     def predict(self, X):
-        if self.preprocessing != 'none':
-            X = self._preprocessor.transform(X)
+        X = self._wt.transform(X)
         
         id_out_of_bounds = np.zeros(X.shape[0]).astype(np.bool)
         for hyp in self._bounds_hyperplanes:
@@ -104,7 +93,6 @@ class ASH(DensityEstimator):
         # f[id_out_of_high_bounds] = 0
 
         # Preprocessing correction
-        if self.preprocessing != 'none':
-            f /= np.product(self._preprocessor.scale_)
-                
+        f /= self._wt.scale_
+        
         return(f)
